#!/bin/sh
#
# CommuniGate  This shell script takes care of starting and stopping
#              the CommuniGate(r) Pro Communication server
#
# FreeBSD version
#
# (c) 1998-2014, Stalker Software, Inc.
#
# APPDIRECTORY  is the CommuniGate Pro application directory location
# (this is a non-modifiable software directory)
# BASEDIRECTORY is the CommuniGate Pro base directory location
# (this directory contains accounts, settings, logs, and other data)
#
APPDIRECTORY="/usr/local/sbin"
BASEDIRECTORY="/var/CommuniGate"
SUPPLPARAMS=""

umask 0

# Custom startup parameters
if [ -f ${BASEDIRECTORY}/Startup.sh ]; then
  . ${BASEDIRECTORY}/Startup.sh
fi

case "$1" in
start)
  if [ ! -d ${BASEDIRECTORY} ] ; then
    if mkdir -p ${BASEDIRECTORY} && chgrp mail ${BASEDIRECTORY} && \
       chmod 0770 ${BASEDIRECTORY} ; then
      echo "CommuniGate Pro Base Directory ${BASEDIRECTORY} created"
    else
      echo "Failed to create the CommuniGate Pro Base Directory ${BASEDIRECTORY}"; exit 1
    fi
  fi

  if [ ! -x ${APPDIRECTORY}/CommuniGate/CGServer ]; then
    echo "CommuniGate Pro Server is not found"; exit 1
  fi

  echo -n "Starting CommuniGate Pro Server"
  if ${APPDIRECTORY}/CommuniGate/CGServer --Base ${BASEDIRECTORY} --Daemon ${SUPPLPARAMS} ; then
    echo ". Started"
  fi
  ;;
stop)
  if [ -f ${BASEDIRECTORY}/ProcessID ]; then
    echo "Shutting down CommuniGate Pro Server"
    if kill `cat ${BASEDIRECTORY}/ProcessID` ; then
      echo -n "Waiting for CommuniGate Pro Server to stop"
      while [ -f ${BASEDIRECTORY}/ProcessID ]; do
        echo -n "."; sleep 1;
      done
      echo ". Stopped"
    fi
  else
    echo "It looks like the CommuniGate Pro Server is not running"
  fi
  ;;
status)
  if [ -f ${BASEDIRECTORY}/ProcessID ]; then
    echo "CommuniGate Pro Server is running. pid=`cat ${BASEDIRECTORY}/ProcessID`"
  else
    echo "CommuniGate Pro Server is not running"
  fi
  ;;
*)
  echo "Usage: $0 [ start | stop | status ]"
  exit 1
  ;;
esac

